Welcome to Polvo
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

<img src="../assets/polvo.png" width=120/>

<!-- <img src="../assets/polvo.png" style="display=block; margin:auto" width=120/> -->

<img src="../assets/polvo.png" style="float: left;" width=120/>

<!-- <h2 style="padding: 00px">Welcome to Polvo</h2> -->
<p style="padding-right: 10px; padding-left: 20px">
Polvo is a collection of computer vision tools that I find helpful for
my personal workflow. Maybe some can be helpful for you too!
</p>

## Install

`pip install polvo`

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
